@@ -1,5 +1,6 @@
 from PythonPals.Button import *
-from PythonPals.questions import *
+
+import questions
 import pygame
 import pygame.gfxdraw
 import textwrap
